==> kio-locate_0.4.0.tar.gz: kio-locate-0.4.0/src/locater.cpp <==
/***************************************************************************
 *   kio-locate: KDE I/O Slave for the locate command                      *
 *                                                                         *
 *   Copyright (C) 2004 by Armin Straub                                    *
 *   linux@arminstraub.de                                                  *
 *                                                                         *
 *   This program was initially written by Michael Schuerig.               *
 *   Although I have completely rewritten it, most ideas are adopted       *
 *   from his original work.                                               *
 *                                                                         *
 *   Copyright (C) 2002 by Michael Schuerig                                *
 *   michael@schuerig.de                                                   *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include <qtextcodec.h>

#include <kdebug.h>

#include "locater.h"


Locater::Locater(QObject *parent, const char *name)
    : QObject(parent, name), m_process(QTextCodec::codecForLocale())
{
    // kdDebug() << "Locater::Locater" << endl;

    connect(&m_process, SIGNAL(processExited(KProcess*)),
            this, SLOT(finished(KProcess*)));
    connect(&m_process, SIGNAL(readReady(KProcIO*)),
            this, SLOT(gotOutput(KProcIO*)));
}


Locater::~Locater()
{
    // kdDebug() << "Locater::~Locater" << endl;
}


void Locater::locate(const QString& pattern, bool ignoreCase)
{
    kdDebug() << "Locater::locate(" << pattern << ")" << endl;

    m_process.resetAll();
    m_process << "locate";
    if (ignoreCase) {
        m_process << "--ignore-case";
    }
    m_process << pattern;

    bool started = m_process.start(KProcess::Block, false);

    if (!started) {
        emit finished();
    }
}

void Locater::stop()
{
    kdDebug() << "Locater::stop()" << endl;

    m_process.kill();
    emit finished();
}


void Locater::gotOutput(KProcIO* /*proc*/)
{
    // kdDebug() << "Locater::gotOutput" << endl;

    QStringList items;
    QString line;

    while (m_process.readln(line) != -1) {
        // kdDebug() << "OUTPUT>> '" << line << "'" << endl;

        items << line;
    }

    emit found(items);
}


void Locater::finished(KProcess* /*proc*/)
{
   // kdDebug() << "Locater::finished" << endl;

   emit finished();
}


#include "locater.moc"

==> kio-locate_0.4.1.tar.gz: kio-locate-0.4.1/src/locater.cpp <==
/***************************************************************************
 *   kio-locate: KDE I/O Slave for the locate command                      *
 *                                                                         *
 *   Copyright (C) 2004 by Armin Straub                                    *
 *   linux@arminstraub.de                                                  *
 *                                                                         *
 *   This program was initially written by Michael Schuerig.               *
 *   Although I have completely rewritten it, most ideas are adopted       *
 *   from his original work.                                               *
 *                                                                         *
 *   Copyright (C) 2002 by Michael Schuerig                                *
 *   michael@schuerig.de                                                   *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include <qtextcodec.h>

#include <kdebug.h>

#include "locater.h"


Locater::Locater(QObject *parent, const char *name)
    : QObject(parent, name), m_process(QTextCodec::codecForLocale())
{
    // kdDebug() << "Locater::Locater" << endl;

    connect(&m_process, SIGNAL(processExited(KProcess*)),
            this, SLOT(finished(KProcess*)));
    connect(&m_process, SIGNAL(readReady(KProcIO*)),
            this, SLOT(gotOutput(KProcIO*)));

    setupLocate();
}


Locater::~Locater()
{
    // kdDebug() << "Locater::~Locater" << endl;
}


void Locater::setupLocate(const QString& binary, const QString& additionalArguments)
{
    kdDebug() << "Locater::setupLocate(" << binary << ", " << additionalArguments << ")" << endl;

    m_locateBinary = binary;
    m_locateAdditionalArguments = additionalArguments;
}


void Locater::locate(const QString& pattern, bool ignoreCase)
{
    kdDebug() << "Locater::locate(" << pattern << ")" << endl;

    m_process.resetAll();
    m_process << m_locateBinary;
    if (!m_locateAdditionalArguments.isEmpty()) {
        m_process << m_locateAdditionalArguments;
    }
    if (ignoreCase) {
        // m_process << "--ignore-case";
        m_process << "-i";
    }
    m_process << pattern;

    bool started = m_process.start(KProcess::Block, false);

    if (!started) {
        emit finished();
    }
}

void Locater::stop()
{
    kdDebug() << "Locater::stop()" << endl;

    m_process.kill();
    emit finished();
}


void Locater::gotOutput(KProcIO* /*proc*/)
{
    // kdDebug() << "Locater::gotOutput" << endl;

    QStringList items;
    QString line;

    while (m_process.readln(line) != -1) {
        // kdDebug() << "OUTPUT>> '" << line << "'" << endl;

        items << line;
    }

    emit found(items);
}


void Locater::finished(KProcess* /*proc*/)
{
   // kdDebug() << "Locater::finished" << endl;

   emit finished();
}


#include "locater.moc"
